# coding: utf-8

"""
    Authress

    <p> <h2>Introduction</h2> <p>Welcome to the Authress Authorization API. <br>The Authress REST API provides the operations and resources necessary to create records, assign permissions, and verify any user in your platform.</p> <p><ul>   <li>Manage multitenant platforms and create user tenants for SSO connections.</li>   <li>Create records to assign roles and resources to grant access for users.</li>   <li>Check user access control by calling the authorization API at the right time.</li>   <li>Configure service clients to securely access services in your platform.</li> </ul></p> <p>For more in-depth scenarios check out the <a href=\"https://authress.io/knowledge-base\" target=\"_blank\">Authress knowledge base</a>.</p> </p>

    The version of the OpenAPI document: v1
    Contact: support@authress.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from authress.models.extension_collection import ExtensionCollection  # noqa: E501

class TestExtensionCollection(unittest.TestCase):
    """ExtensionCollection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtensionCollection:
        """Test ExtensionCollection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtensionCollection`
        """
        model = ExtensionCollection()  # noqa: E501
        if include_optional:
            return ExtensionCollection(
                extensions = [
                    authress.models.extension.Extension(
                        extension_id = '0', 
                        name = 'Extension: third party example', 
                        created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        application = authress.models.extension_application.ExtensionApplication(
                            application_id = '', 
                            redirect_urls = [
                                ''
                                ], 
                            links = authress.models.links.Links(
                                self = authress.models.link.Link(
                                    href = '', 
                                    rel = '', ), ), ), 
                        client = authress.models.extension_client.ExtensionClient(
                            client_id = '', 
                            rate_limits = [
                                authress.models.client_rate_limit.ClientRateLimit(
                                    duration = 'PT0S', 
                                    quota = 100, )
                                ], ), 
                        tags = {"environment":"production"}, )
                    ],
                pagination = authress.models.pagination.Pagination(
                    next = authress.models.pagination_next.Pagination_next(
                        cursor = '', ), )
            )
        else:
            return ExtensionCollection(
                extensions = [
                    authress.models.extension.Extension(
                        extension_id = '0', 
                        name = 'Extension: third party example', 
                        created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        application = authress.models.extension_application.ExtensionApplication(
                            application_id = '', 
                            redirect_urls = [
                                ''
                                ], 
                            links = authress.models.links.Links(
                                self = authress.models.link.Link(
                                    href = '', 
                                    rel = '', ), ), ), 
                        client = authress.models.extension_client.ExtensionClient(
                            client_id = '', 
                            rate_limits = [
                                authress.models.client_rate_limit.ClientRateLimit(
                                    duration = 'PT0S', 
                                    quota = 100, )
                                ], ), 
                        tags = {"environment":"production"}, )
                    ],
        )
        """

    def testExtensionCollection(self):
        """Test ExtensionCollection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
