# coding: utf-8

"""
    Authress

    <p> <h2>Introduction</h2> <p>Welcome to the Authress Authorization API. <br>The Authress REST API provides the operations and resources necessary to create records, assign permissions, and verify any user in your platform.</p> <p><ul>   <li>Manage multitenant platforms and create user tenants for SSO connections.</li>   <li>Create records to assign roles and resources to grant access for users.</li>   <li>Check user access control by calling the authorization API at the right time.</li>   <li>Configure service clients to securely access services in your platform.</li> </ul></p> <p>For more in-depth scenarios check out the <a href=\"https://authress.io/knowledge-base\" target=\"_blank\">Authress knowledge base</a>.</p> </p>

    The version of the OpenAPI document: v1
    Contact: support@authress.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
try:
    from pydantic.v1 import BaseModel, Field, StrictStr, conint, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, conint, validator

class ClientRateLimit(BaseModel):
    """
    A service client rate limit. Rate Limits can be used to prevent service clients from creating too many requests to your API. They can also limit the number of requests to Authress management APIs, or contain a maximum quota for a client before it is not longer allowed to make additional requests.  # noqa: E501
    """
    duration: StrictStr = Field(default=..., description="The sliding window timeslice duration for which this quota applies. This value must conform to the ISO8601 format, see the enum for allow values.")
    quota: Optional[conint(strict=True, le=1000000, ge=100)] = Field(default=..., description="The maximum number of requests allowed during the duration.")
    __properties = ["duration", "quota"]

    @validator('duration')
    def duration_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('PT0S', 'P1M', 'P1D', 'PT1H', 'PT5M'):
            raise ValueError("must be one of enum values ('PT0S', 'P1M', 'P1D', 'PT1H', 'PT5M')")
        return value

    @validator('quota')
    def quota_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (100, 1000, 100000, 1000000):
            raise ValueError("must be one of enum values (100, 1000, 100000, 1000000)")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ClientRateLimit:
        """Create an instance of ClientRateLimit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if quota (nullable) is None
        # and __fields_set__ contains the field
        if self.quota is None and "quota" in self.__fields_set__:
            _dict['quota'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ClientRateLimit:
        """Create an instance of ClientRateLimit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ClientRateLimit.parse_obj(obj)

        _obj = ClientRateLimit.parse_obj({
            "duration": obj.get("duration"),
            "quota": obj.get("quota")
        })
        return _obj


